(***********************************************************************)
(*                                                                     *)
(*                              My_stdlib                              *)
(*                                                                     *)
(*             projets Estime & Cristal, INRIA-Rocquencourt            *)
(*                                                                     *)
(*  Copyright 2004-2006 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: my_options.ml,v 1.1 2007/01/17 23:36:00 fclement Exp $ *)

let aref default =
  let r = ref default in
  (fun x -> r := x),
  (fun () -> !r);;

let saref s default =
  let set = ref false in
  let r = ref default in
  (fun x ->
    if !set then
      begin prerr_endline ("Attempt to set twice saref " ^ s); exit 5 end
    else begin r := x; set := true end),
  (fun () -> !r);;

let uaref s default =
  let set = ref false in
  let r = ref default in
  (fun x ->
    if !set then
      begin prerr_endline ("Attempt to set twice uaref " ^ s); exit 5 end
    else r := x;
    set := true),
  (fun () ->
    if not !set then
      begin prerr_endline ("Attempt to get undefined uaref " ^ s); exit 5 end
    else !r);;

let optref s =
  let r = ref None in
  (fun x -> r := Some x),
  (fun () ->
    match !r with
    | None -> prerr_endline ("Undefined optional ref variable " ^ s); exit 5
    | Some x -> x);;

let malref default =
  let set = ref false in
  let r = ref default in
  (fun x -> if not !set then r := []; set := true; r := x :: !r),
  (fun () -> !r);;

let man_with_default = Printf.sprintf "%s\n\tDefault is %s.";;

let man_with_default_and_valid =
  Printf.sprintf "%s\n\tDefault is %s.\n\tValid entries are: %s.";;
